export class AbstractActivityRecognizer {
    constructor(recognizerType, recognizerState, callbackManager, recognitionManager) {
        this.recognizerType = recognizerType;
        this.recognizerState = recognizerState;
        this.callbackManager = callbackManager;
        this.recognitionManager = recognitionManager;
    }
    isReady() {
        return this.recognitionManager.isReady();
    }
    async prepare() {
        await this.recognitionManager.prepare();
    }
    async setup() {
        const active = await this.recognizerState.isActive(this.recognizerType);
        if (active) {
            const startOptions = await this.recognizerState.getStartOptions(this.recognizerType);
            await this.recognitionManager.startListening(startOptions);
        }
    }
    async startRecognizing(options = {}) {
        await this.recognitionManager.startListening(options);
        const active = await this.recognizerState.isActive(this.recognizerType);
        if (active) {
            return;
        }
        await this.recognizerState.markAsActive(this.recognizerType, options);
    }
    async stopRecognizing() {
        try {
            await this.recognitionManager.stopListening();
        }
        catch (e) {
            console.error(`Could not deactivate ${this.recognizerType} res activity recognizer: ${e.stack ? e.stack : e}`);
        }
        await this.recognizerState.markAsInactive(this.recognizerType);
    }
    listenActivityChanges(callback) {
        return this.callbackManager.add(callback);
    }
    stopListening(listenerId) {
        if (typeof listenerId === "number") {
            this.callbackManager.remove(listenerId);
        }
        else {
            this.callbackManager.removeAll();
        }
    }
}
//# sourceMappingURL=abstract-recognizer.js.map